#
# spec file for package blobwars
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           blobwars
Version:        2.00
Release:        bp153.1.20
Summary:        Mission and Objective based 2D Platform Game
License:        GPL-2.0+
Group:          Amusements/Games/Action/Arcade
Url:            http://sourceforge.net/projects/blobwars/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}.appdata.xml
# PATCH-FIX-OPENSUSE - blobwars-icons_blobwars.desktop.patch -- Add GenericName and Category
Patch0:         %{name}-icons_blobwars.desktop.patch
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/blobwars/patches/8/
Patch1:         reproducible.patch
%if 0%{?suse_version}
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
%endif
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Blob Wars : Metal Blob Solid. This is Episode I of the Blob Wars Saga.
This is a platform game, not unlike those found on the Amiga and SNES.
The object of the game is to take on the role of solider Blob, Bob,
and play through the various levels and attempt to rescue as many MIA
(Missing In Action) Blobs as possible. This is not quite as straight
forward as it sounds, since the MIAs will often be not directly
reachable and will require some extra thought. Bob also has to
contend with environmental hazards, alien invaders and assimilated Blobs.

%lang_package

%prep
%setup -q
%patch0
%patch1 -p1

# Correct Permissions
chmod 0644 Makefile*

# SED-FIX-OPENSUSE -- Fix paths and libraries
sed -i -e 's|USEPAK ?= 0|USEPAK ?= 1|;
           s|$(PREFIX)/games|$(PREFIX)/bin|;
           s|$(PREFIX)/share/games|$(PREFIX)/share|;
           s| -Werror||;
           s|$(CXX) $(LIBS) $(GAMEOBJS) -o $(PROG)|$(CXX) $(GAMEOBJS) $(LIBS) -o $(PROG)|;
           s|$(CXX) $(LIBS) $(PAKOBJS) -o pak|$(CXX) $(PAKOBJS) $(LIBS) -o pak|;
           s|$(CXX) $(LIBS) $(MAPOBJS) -o mapeditor|$(CXX) $(MAPOBJS) $(LIBS) -o mapeditor|' Makefile

# SED-FIX-OPENSUSE -- Fix pak
sed -i -e 's|gzclose(pak)|gzclose((gzFile)pak)|;
           s|gzclose(fp)|gzclose((gzFile)fp)|' src/pak.cpp

%build
make %{?_smp_mflags} CFLAGS="%{optflags}" \
     RELEASE=1 DOCDIR=%{_docdir}/%{name}/

%install
#make install
%make_install BINDIR=%{_bindir}/ DATADIR=%{_datadir}/%{name}/ DOCDIR=%{_docdir}/%{name}/

# install icons
for i in 16 32 48 64; do
    install -Dm 0644 icons/%{name}${i}x${i}.png \
            %{buildroot}/%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

%find_lang %{name}

# Install appdata
mkdir -p %{buildroot}%{_datadir}/appdata
install -Dm 0644 %{S:1} %{buildroot}%{_datadir}/appdata

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
%endif

%files
%defattr(-,root,root)
%doc doc/*
%{_bindir}/%{name}
%{_datadir}/%{name}
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%files lang -f %{name}.lang

%changelog
* Thu Jul 20 2017 bwiedemann@suse.com
- Add reproducible.patch to sort file list to fix build-compare (boo#1041090)
* Wed Nov 25 2015 nemysis@openSUSE.org
- Update to 2.00, announce message:
  * Changed to SDL 2.0. This also allows the window to be scaled to an arbitrary
  size, and doesn't change the desktop resolution anymore when going to
  fullscreen.
  * The joystick/gamepad can now also be used in the menus and on the hub.
  * Updated credits and copyright notices.
  * Added stereo to the sound effects.
  * Cleaned up some graphics.
  * Fixed the machinegun sound.
  * Fixed the behaviour of grenades.
  * Many small fixes.
- Remove icons blobwars-icons.tar, use supplied
- Change BuildRequires, changed by Upstream for SDL2
- Change sed, use Makefile instead of makefile, changed by Upstream
* Sat Jun 27 2015 nemysis@gmx.ch
- Modernize spec
- Use sed instead of simple patches
- Remove patches blobwars-1.19-makefile.patch, blobwars-1.05-debian.patch,
  blobwars-1.19-check-chdir-ret.patch, blobwars-1.14-as_needed.patch
- Add patch blobwars-icons_blobwars.desktop.patch
- Change Source0 to use Web URL
- Add icons, use blobwars-icons.tar
- Use %%{name} instead of blobwars
- Add BuildRequires for pkgconfig
- Use check for openSUSE %%if 0%%{?suse_version}
- Use BuildRequires pkgconfig() instead of devel packages
- Remove Recommends for blobwars-lang = %%{version}, because
  is default installed
- Change Description
- Use chmod 0644 makefile* instead of chmod a-x src/* doc/*
- Add sed, Fix paths and libraries
- Add sed, Fix pak
* Mon Oct  6 2014 dimstar@opensuse.org
- Add bobwars.appdata.xml to the package for software centers.
* Wed Mar 27 2013 joop.boonen@opensuse.org
- Updated the License
* Sat May  5 2012 reddwarf@opensuse.org
- Make it start (bnc#760845)
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Tue May  3 2011 claes.backstrom@opensuse.org
- New upstream release 1.19
  * Fixed medal support.
  * Corrected the credits for the song Herbs from Ambick, which
    is a modified version of Claustrophobia from LizardKing.
- Respin of makefile patch and use patch from debian
- Add new check-chdir patch
- Removed patch for desktop file fixed upstream
- Removed build requirement of licenses
* Sat Apr  2 2011 toddrme2178@gmail.com
- New upstream release 1.18
  * Updated Catalan and Dutch translations.
  * Minor spelling errors fixed.
  * Moved desktop entry from Applicaitons to ArcadeGame section.
  * Perform a sanitiy check when loading keyboard.cfg.
  * Allow the game to run without music and sounds.
  * Fixed bug preventing long messages to be seen.
  * Briefly show music credits at the start of a level.
  * Fixed bugs found by Valgrind and Cppcheck.
  * Prevent the player from getting the JetPack too early.
  * Added Free music and sound effects.
  * Added exit screen.
- New upstream release 1.17
  * Add medal support.
- Removed separate music tarball since music is now included
- Remove build tests for obsolete openSUSE versions
- Respin of makefile patchs
- Moved to Amusements/Games/Arcade based on upstream spec file
* Sun Sep 13 2009 cmorve69@yahoo.es
- Readd missing icons
- Patch to compile with --as-needed
* Wed Aug 12 2009 claes.backstrom@fsfe.org
- New upstream release 1.14
  * This update fixes some issues with loading missions and when
    changing or restarting a level when holding special items,
    such as grappling hooks.
- Removed upstreamed blobwars-1.11-es.patch and
  blobwars-1.11-es-title.patch
- Removed Autoreqprov
- Respin of makefile patch
- Added SUSE_ASNEEDED=0 to get it to build
* Sat Apr 11 2009 claes.backstrom@fsfe.orrg
- Remove nonfree sounds and music
- Update to 1.11
* Wed Nov 21 2007 claes.backstrom@fsfe.org
- Initial package built from Fedora package (1.07-2)
